"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.selectAll = selectAll;
exports.selectAllFiltered = selectAllFiltered;
exports.unselectAll = unselectAll;
exports.unselectAllFiltered = unselectAllFiltered;
var _treeView = require("../store/treeView.store");
var _toggleCheckbox = require("./toggleCheckbox.helper");
/**
 * Selects all nodes that are currently visible due to the applied filter.
 * 
 * If there is no search text, then it selects all nodes; otherwise, it selects all visible nodes.
 */
function selectAllFiltered() {
  const {
    searchText,
    innerMostChildrenIds
  } = _treeView.useTreeViewStore.getState();

  // If there's no search text, select all nodes
  if (!searchText) {
    selectAll();
  } else {
    // If there's search text, only select the visible nodes
    (0, _toggleCheckbox.toggleCheckboxes)(innerMostChildrenIds, true);
  }
}
;

/**
 * Unselects all nodes that are currently visible due to the applied filter.
 * 
 * If there is no search text, then it unselects all nodes; otherwise, it unselects all visible nodes.
 */
function unselectAllFiltered() {
  const {
    searchText,
    innerMostChildrenIds
  } = _treeView.useTreeViewStore.getState();

  // If there's no search text, unselect all nodes
  if (!searchText) {
    unselectAll();
  } else {
    // If there's search text, only unselect the visible nodes
    (0, _toggleCheckbox.toggleCheckboxes)(innerMostChildrenIds, false);
  }
}
;

/**
 * Selects all nodes in the tree.
 * 
 * This function selects all nodes by adding all node ids to the checked set and clearing the indeterminate set.
 */
function selectAll() {
  const {
    nodeMap,
    updateChecked,
    updateIndeterminate
  } = _treeView.useTreeViewStore.getState();

  // Create a new set containing the ids of all nodes
  const newChecked = new Set(nodeMap.keys());
  // Update the state to mark all nodes as checked

  updateChecked(newChecked);
  updateIndeterminate(new Set());
}
;

/**
 * Unselects all nodes in the tree.
 * 
 * This function unselects all nodes by clearing both the checked and indeterminate sets.
 */
function unselectAll() {
  const {
    updateChecked,
    updateIndeterminate
  } = _treeView.useTreeViewStore.getState();
  // Update the state to mark all nodes as unchecked

  updateChecked(new Set());
  updateIndeterminate(new Set());
}
;
//# sourceMappingURL=selectAll.helper.js.map